@@ -1,7 +1,7 @@
+#include <cstdint>
 #include "port.h"
-BASE_CC_FILE
 
-#include <error.h>
+#include <cmath>
 
 #include "rdbinterval.h"
 #include "rdbprogress.h"
@@ -11,12 +11,6 @@ BASE_CC_FILE
 #include "GenomeTrackRects.h"
 #include "GenomeTrackSparse.h"
 
-#ifdef __GXX_EXPERIMENTAL_CXX0X__
-#ifndef isnan
-#define isnan ::isnan
-#endif
-#endif
-
 using namespace std;
 using namespace rdb;
 
@@ -41,7 +35,7 @@ public:
 	}
 
 	void write_interval(const GInterval &interval, float val) {
-		if ((isnan(val) && isnan(m_last_val) || val == m_last_val) && m_last_interval.end == interval.start)
+		if (((std::isnan(val) && std::isnan(m_last_val)) || val == m_last_val) && m_last_interval.end == interval.start)
 			m_last_interval.end = interval.end;
 		else {
 			flush();
@@ -91,7 +85,7 @@ private:
 	void write_last_interval() {
 		static const int RECORD_SIZE = sizeof(m_last_interval.start) + sizeof(m_last_interval.end) + sizeof(m_last_val);
 
-		size_t size = 0;
+		uint64_t size = 0;
 		size += m_bfile.write(&m_last_interval.start, sizeof(m_last_interval.start));
 		size += m_bfile.write(&m_last_interval.end, sizeof(m_last_interval.end));
 		size += m_bfile.write(&m_last_val, sizeof(m_last_val));
@@ -129,7 +123,7 @@ public:
 	void write_interval(const GInterval &interval1, const GInterval &interval2, float val) {
 		static const int RECORD_SIZE = sizeof(interval1.start) + sizeof(interval2.start) + sizeof(interval1.end) + sizeof(interval2.end) + sizeof(val);
 
-		size_t size = 0;
+		uint64_t size = 0;
 		size += m_bfile.write(&interval1.start, sizeof(interval1.start));
 		size += m_bfile.write(&interval1.end, sizeof(interval1.end));
 		size += m_bfile.write(&interval2.start, sizeof(interval2.start));
@@ -238,7 +232,7 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 			// create temporary files that contain unsorted target intervals and corresponding values
 			for (vector<BufferedIntervals>::iterator ibuffered_interv = buffered_intervs.begin(); ibuffered_interv != buffered_intervs.end(); ++ibuffered_interv) {
 				int chromid = ibuffered_interv - buffered_intervs.begin();
-				sprintf(filename, "%s/_%s", dirname.c_str(), iu.get_chromkey().id2chrom(chromid).c_str());
+				snprintf(filename, sizeof(filename), "%s/_%s", dirname.c_str(), iu.get_chromkey().id2chrom(chromid).c_str());
 				ibuffered_interv->open(filename, "w+", chromid);
 			}
 
@@ -250,11 +244,11 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 					float val;
 
 					try {
-						sprintf(filename, "%s/%s", src_track_dir, ichrom->c_str());
+						snprintf(filename, sizeof(filename), "%s/%s", src_track_dir, ichrom->c_str());
 						src_track.init_read(filename, chromid);
 						if (binsize > 0 && binsize != src_track.get_bin_size()) {
 							char filename2[FILENAME_MAX];
-							sprintf(filename2, "%s/%s", src_track_dir, (ichrom - 1)->c_str());
+							snprintf(filename2, sizeof(filename2), "%s/%s", src_track_dir, (ichrom - 1)->c_str());
 							TGLError("Binsize of track file %s differs from the binsize of track file %s (%d vs. %d)",
 									filename, filename2, src_track.get_bin_size(), binsize);
 						} else
@@ -287,7 +281,7 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 					int chromid = ichrom - src_id2chrom.begin();
 
 					try {
-						sprintf(filename, "%s/%s", src_track_dir, ichrom->c_str());
+						snprintf(filename, sizeof(filename), "%s/%s", src_track_dir, ichrom->c_str());
 						src_track.init_read(filename, chromid);
 					} catch (TGLException &) {  // some of source chroms might be missing, this is normal
 						progress.report(1);
@@ -298,7 +292,7 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 					const vector<float> &vals = src_track.get_vals();
 					ChainIntervals::const_iterator hint = chain_intervs.begin();
 
-					for (size_t i = 0; i < src_intervals.size(); ++i) {
+					for (uint64_t i = 0; i < src_intervals.size(); ++i) {
 						hint = chain_intervs.map_interval(src_intervals[i], tgt_intervals, hint);
 						for (GIntervals::const_iterator iinterv = tgt_intervals.begin(); iinterv != tgt_intervals.end(); ++iinterv)
 							buffered_intervs[iinterv->chromid].write_interval(*iinterv, vals[i]);
@@ -323,7 +317,7 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 
 				sort(interv_vals.begin(), interv_vals.end());
 
-				sprintf(filename, "%s/%s", dirname.c_str(), GenomeTrack::get_1d_filename(iu.get_chromkey(), chromid).c_str());
+				snprintf(filename, sizeof(filename), "%s/%s", dirname.c_str(), GenomeTrack::get_1d_filename(iu.get_chromkey(), chromid).c_str());
 
 				if (src_track_type == GenomeTrack::FIXED_BIN) {
 					GenomeTrackFixedBin gtrack;
@@ -341,7 +335,7 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 						for ( ; iinterv_val != interv_vals.end(); ++iinterv_val) {
 							if (max(coord1, iinterv_val->interval.start) < min(coord2, iinterv_val->interval.end)) {
 								intersect = true;
-								if (!isnan(iinterv_val->val)) {
+								if (!std::isnan(iinterv_val->val)) {
 									sum += iinterv_val->val;
 									++num_intervals;
 								}
@@ -411,7 +405,7 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 					int chromid2 = ichrom2 - src_id2chrom.begin();
 
 					try {
-						sprintf(filename, "%s/%s-%s", src_track_dir, ichrom1->c_str(), ichrom2->c_str());
+						snprintf(filename, sizeof(filename), "%s/%s-%s", src_track_dir, ichrom1->c_str(), ichrom2->c_str());
 						src_track->init_read(filename, chromid1, chromid2);
 						if (!src_track->opened()) {
 							progress.report(1);
@@ -446,7 +440,7 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 								for (GIntervals::const_iterator iinterv2 = tgt_intervals[1].begin(); iinterv2 != tgt_intervals[1].end(); ++iinterv2) {
 									int idx = iinterv1->chromid * iu.get_chromkey().get_num_chroms() + iinterv2->chromid;
 									if (!buffered_intervs[idx].opened()) {
-										sprintf(filename, "%s/_%s-%s", dirname.c_str(), iu.get_chromkey().id2chrom(iinterv1->chromid).c_str(), iu.get_chromkey().id2chrom(iinterv2->chromid).c_str());
+										snprintf(filename, sizeof(filename), "%s/_%s-%s", dirname.c_str(), iu.get_chromkey().id2chrom(iinterv1->chromid).c_str(), iu.get_chromkey().id2chrom(iinterv2->chromid).c_str());
 										buffered_intervs[idx].open(filename, "w+", iinterv1->chromid, iinterv2->chromid);
 									}
 									buffered_intervs[idx].write_interval(*iinterv1, *iinterv2, iqtree->v);
@@ -472,7 +466,7 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 								for (GIntervals::const_iterator iinterv2 = tgt_intervals[1].begin(); iinterv2 != tgt_intervals[1].end(); ++iinterv2) {
 									int idx = iinterv1->chromid * iu.get_chromkey().get_num_chroms() + iinterv2->chromid;
 									if (!buffered_intervs[idx].opened()) {
-										sprintf(filename, "%s/_%s-%s", dirname.c_str(), iu.get_chromkey().id2chrom(iinterv1->chromid).c_str(), iu.get_chromkey().id2chrom(iinterv2->chromid).c_str());
+										snprintf(filename, sizeof(filename), "%s/_%s-%s", dirname.c_str(), iu.get_chromkey().id2chrom(iinterv1->chromid).c_str(), iu.get_chromkey().id2chrom(iinterv2->chromid).c_str());
 										buffered_intervs[idx].open(filename, "w+", iinterv1->chromid, iinterv2->chromid);
 									}
 									buffered_intervs[idx].write_interval(*iinterv1, *iinterv2, iqtree->v);
@@ -504,7 +498,7 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 					if (!qtree.empty()) {
 						GenomeTrackRectsRects gtrack(iu.get_track_chunk_size(), iu.get_track_num_chunks());
 
-						sprintf(filename, "%s/%s", dirname.c_str(), GenomeTrack::get_2d_filename(iu.get_chromkey(), chromid1, chromid2).c_str());
+						snprintf(filename, sizeof(filename), "%s/%s", dirname.c_str(), GenomeTrack::get_2d_filename(iu.get_chromkey(), chromid1, chromid2).c_str());
 						gtrack.init_write(filename, chromid1, chromid2);
 						gtrack.write(qtree);
 					}
@@ -526,7 +520,9 @@ SEXP gtrack_liftover(SEXP _track, SEXP _src_track_dir, SEXP _chain, SEXP _envir)
 		}
 	} catch (TGLException &e) {
 		rerror("%s", e.msg());
-	}
+    } catch (const bad_alloc &e) {
+        rerror("Out of memory");
+    }
 
 	return R_NilValue;
 }
