@@ -1,3 +1,4 @@
+#include <cstdint>
 #include "GIntervalsBigSet1D.h"
 #include "GenomeSeqFetch.h"
 #include "rdbinterval.h"
@@ -16,7 +17,7 @@ SEXP gseqread(SEXP _intervals, SEXP _envir)
 		IntervUtils iu(_envir);
 		GIntervalsFetcher1D *intervals = NULL;
 		iu.convert_rintervs(_intervals, &intervals, NULL);
-		auto_ptr<GIntervalsFetcher1D> intervals_guard(intervals);
+		unique_ptr<GIntervalsFetcher1D> intervals_guard(intervals);
 		intervals->sort();
 
 		if (!intervals->size())
@@ -24,7 +25,7 @@ SEXP gseqread(SEXP _intervals, SEXP _envir)
 
 		vector<char> buf;
 		SEXP answer;
-		rprotect(answer = allocVector(STRSXP, intervals->size()));
+		rprotect(answer = RSaneAllocVector(STRSXP, intervals->size()));
 
 		uint64_t seqlen = 0;
 		GenomeSeqFetch seqfetch;
@@ -41,7 +42,9 @@ SEXP gseqread(SEXP _intervals, SEXP _envir)
 		return answer;
 	} catch (TGLException &e) {
 		rerror("%s", e.msg());
-	}
+    } catch (const bad_alloc &e) {
+        rerror("Out of memory");
+    }
 	return R_NilValue;
 }
 
